apache_error

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ApacheErrorLogGenerator

type ApacheErrorLogGenerator struct {
	// contains filtered or unexported fields
}

ApacheErrorLogGenerator generates Apache Error Log Format log data

func New

func New(logger *zap.Logger, workers int, rate time.Duration) (*ApacheErrorLogGenerator, error)

New creates a new Apache Error log generator

func (*ApacheErrorLogGenerator) SetCountTracker added in v0.13.0

func (g *ApacheErrorLogGenerator) SetCountTracker(t *count.Tracker)

SetCountTracker sets the finite generation count tracker.

func (*ApacheErrorLogGenerator) Start

func (g *ApacheErrorLogGenerator) Start(writer output.Writer) error

Start starts the Apache Error log generator and writes data using the provided generator writer.

func (*ApacheErrorLogGenerator) Stop

Stop stops the Apache Error log generator and waits for all workers to finish.

Jump to