nginx

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Generator

type Generator struct {
	// contains filtered or unexported fields
}

Generator generates NGINX Combined Log Format log data

func New

func New(logger *zap.Logger, workers int, rate time.Duration) (*Generator, error)

New creates a new NGINX log generator

func (*Generator) SetCountTracker added in v0.13.0

func (g *Generator) SetCountTracker(t *count.Tracker)

SetCountTracker sets the finite generation count tracker.

func (*Generator) Start

func (g *Generator) Start(writer output.Writer) error

Start starts the NGINX log generator and writes data using the provided generator writer.

func (*Generator) Stop

func (g *Generator) Stop(ctx context.Context) error

Stop stops the NGINX log generator and waits for all workers to finish.

Jump to