package
Version:
v0.14.0
Opens a new window with list of versions in this module.
Published: May 14, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Info struct {
Version string `json:"version"`
BuildTime string `json:"buildTime"`
BuildPlatform string `json:"buildPlatform"`
BinaryPlatform string `json:"binaryPlatform"`
Commit string `json:"commit"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.