logging

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 7, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package logging contains the logging logic for Blitz

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLogger

func NewLogger(cfg loaderconfig.Logging) (*zap.Logger, error)

NewLogger returns a new Logger for the specified config. If the config is empty, it defaults to stdout at info level.

Types

This section is empty.

Jump to