telemetry

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 21, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package telemetry defines the supported telemetry signal types for blitz.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Supports

func Supports(supported []Type, target Type) bool

Supports returns true if the given type is present in the supported slice.

func Validate

func Validate(generator, output []Type) error

Validate checks that the generator and output telemetry types have at least one overlapping type. Returns an error if there is no overlap.

Types

type Type

type Type string

Type represents a telemetry signal type.

const (
	// Logs represents log telemetry.
	Logs Type = "logs"
	// Metrics represents metric telemetry.
	Metrics Type = "metrics"
	// Traces represents trace telemetry.
	Traces Type = "traces"
)

func (Type) Valid

func (t Type) Valid() bool

Valid returns true if the type is a known telemetry type.

Jump to