generator

package
v0.15.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (

	// BlitzGeneratorEntriesCounter tracks the total number of telemetry entries generated
	BlitzGeneratorEntriesCounter BlitzGeneratorEntriesCounterType

	// BlitzGeneratorActiveWorkersGauge tracks the number of active worker goroutines
	BlitzGeneratorActiveWorkersGauge BlitzGeneratorActiveWorkersGaugeType

	// BlitzGeneratorWriteErrorsCounter tracks the total number of write errors
	BlitzGeneratorWriteErrorsCounter BlitzGeneratorWriteErrorsCounterType

	// error_type
	AttrErrorTypeUnknown = attribute.String(attrErrorType, string(ErrorTypeUnknown))
	AttrErrorTypeTimeout = attribute.String(attrErrorType, string(ErrorTypeTimeout))
)

Functions

This section is empty.

Types

type BlitzGeneratorActiveWorkersGaugeType added in v0.14.0

type BlitzGeneratorActiveWorkersGaugeType struct {
	// contains filtered or unexported fields
}

BlitzGeneratorActiveWorkersGaugeType wraps the blitz.generator.active_workers metric with type-safe required attributes

func (BlitzGeneratorActiveWorkersGaugeType) Record added in v0.14.0

func (m BlitzGeneratorActiveWorkersGaugeType) Record(ctx context.Context, value int64, generatorType string, opts ...metric.RecordOption)

Record records a value for blitz.generator.active_workers with required attributes

type BlitzGeneratorEntriesCounterType added in v0.14.0

type BlitzGeneratorEntriesCounterType struct {
	// contains filtered or unexported fields
}

BlitzGeneratorEntriesCounterType wraps the blitz.generator.entries metric with type-safe required attributes

func (BlitzGeneratorEntriesCounterType) Add added in v0.14.0

func (m BlitzGeneratorEntriesCounterType) Add(ctx context.Context, value int64, generatorType string, opts ...metric.AddOption)

Add records a value for blitz.generator.entries with required attributes

type BlitzGeneratorWriteErrorsCounterType added in v0.14.0

type BlitzGeneratorWriteErrorsCounterType struct {
	// contains filtered or unexported fields
}

BlitzGeneratorWriteErrorsCounterType wraps the blitz.generator.write_errors metric with type-safe required attributes

func (BlitzGeneratorWriteErrorsCounterType) Add added in v0.14.0

func (m BlitzGeneratorWriteErrorsCounterType) Add(ctx context.Context, value int64, generatorType string, opts ...metric.AddOption)

Add records a value for blitz.generator.write_errors with required attributes

type ErrorTypeValue added in v0.14.0

type ErrorTypeValue string

ErrorTypeValue is the type of the error_type enum attribute

const (
	ErrorTypeUnknown ErrorTypeValue = "unknown"
	ErrorTypeTimeout ErrorTypeValue = "timeout"
)

type Generator

type Generator interface {
	// Start starts the generator and writes data using the
	// provided generator writer.
	Start(writer output.Writer) error

	// Stop stops the generator.
	Stop(ctx context.Context) error
}

Generator is the interface for generating data.

Directories

Path Synopsis

Jump to