Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApacheLogGenerator ¶
type ApacheLogGenerator struct {
embed.ProducerMarker
// contains filtered or unexported fields
}
ApacheLogGenerator generates Apache Common Log Format (CLF) log data
func New ¶
func New(logger *zap.Logger, workers int, rate time.Duration, consumer embed.LogConsumer) (*ApacheLogGenerator, error)
New creates a new Apache log generator. The consumer receives each generated record as a size-1 batch via ConsumeLogs.
func (*ApacheLogGenerator) Name ¶ added in v0.16.0
func (g *ApacheLogGenerator) Name() string
Name returns the module identifier.
func (*ApacheLogGenerator) SetCountTracker ¶ added in v0.13.0
func (g *ApacheLogGenerator) SetCountTracker(t *count.Tracker)
SetCountTracker sets the finite generation count tracker.
func (*ApacheLogGenerator) Start ¶
func (g *ApacheLogGenerator) Start(_ context.Context) error
Start launches the worker goroutines that push generated records to the configured consumer. Start returns once workers are running.
func (*ApacheLogGenerator) Stop ¶
func (g *ApacheLogGenerator) Stop(ctx context.Context) error
Stop stops the Apache log generator. This function expects to be called exactly once.
func (*ApacheLogGenerator) SupportedTelemetry ¶ added in v0.16.0
func (g *ApacheLogGenerator) SupportedTelemetry() []telemetry.Type
SupportedTelemetry returns the telemetry types this generator produces.
Click to show internal directories.
Click to hide internal directories.