Documentation
¶
Index ¶
- type ApacheErrorLogGenerator
- func (g *ApacheErrorLogGenerator) Name() string
- func (g *ApacheErrorLogGenerator) SetCountTracker(t *count.Tracker)
- func (g *ApacheErrorLogGenerator) Start(_ context.Context) error
- func (g *ApacheErrorLogGenerator) Stop(ctx context.Context) error
- func (g *ApacheErrorLogGenerator) SupportedTelemetry() []telemetry.Type
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApacheErrorLogGenerator ¶
type ApacheErrorLogGenerator struct {
embed.ProducerMarker
// contains filtered or unexported fields
}
ApacheErrorLogGenerator generates Apache Error Log Format log data
func New ¶
func New(logger *zap.Logger, workers int, rate time.Duration, consumer embed.LogConsumer) (*ApacheErrorLogGenerator, error)
New creates a new Apache Error log generator. The consumer receives each generated record as a size-1 batch via ConsumeLogs.
func (*ApacheErrorLogGenerator) Name ¶ added in v0.16.0
func (g *ApacheErrorLogGenerator) Name() string
Name returns the module identifier.
func (*ApacheErrorLogGenerator) SetCountTracker ¶ added in v0.13.0
func (g *ApacheErrorLogGenerator) SetCountTracker(t *count.Tracker)
SetCountTracker sets the finite generation count tracker.
func (*ApacheErrorLogGenerator) Start ¶
func (g *ApacheErrorLogGenerator) Start(_ context.Context) error
Start launches the worker goroutines that push generated records to the configured consumer.
func (*ApacheErrorLogGenerator) Stop ¶
func (g *ApacheErrorLogGenerator) Stop(ctx context.Context) error
Stop stops the Apache Error log generator and waits for all workers to finish.
func (*ApacheErrorLogGenerator) SupportedTelemetry ¶ added in v0.16.0
func (g *ApacheErrorLogGenerator) SupportedTelemetry() []telemetry.Type
SupportedTelemetry returns the telemetry types this generator produces.
Click to show internal directories.
Click to hide internal directories.