service

package
v0.10.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	Logger    *zap.Logger
	Generator generator.Generator
	Output    output.Output
}

func New

func New(logger *zap.Logger, generator generator.Generator, output output.Output) (*Service, error)

func (*Service) Start

func (s *Service) Start() error

Start starts the service.

func (*Service) Stop

func (s *Service) Stop() error

Stop stops the service. Stop will block for up to 30 seconds. If the generator or output do not stop within the timeout, an error will be returned and the program can exit.

Jump to