Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RandomUserAgent ¶
RandomUserAgent returns a random user agent string weighted by real-world prevalence. More common browsers are selected more frequently based on their market share.
Types ¶
type UserAgent ¶
UserAgent represents a user agent string with its relative weight/frequency Weight represents the real-world prevalence of this user agent
func UserAgents ¶
func UserAgents() []UserAgent
UserAgents returns a slice of all available user agents for reference/testing
Click to show internal directories.
Click to hide internal directories.