Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Host string
Port int
Transport Transport
RFC RFCMode
Workers int
// Facility is 0-23
Facility int
AppName string
Hostname string
ProcID string
MsgID string
// UDP-only safety limit. If <= 0, no truncation is attempted.
// If positive and message exceeds the limit, it will be truncated.
MaxDatagramBytes int
// TCP-only TLS configuration. If nil, TLS is disabled.
TLSConfig *tls.Config
}
Config controls syslog message formatting and transport behavior.
type Syslog ¶
type Syslog struct {
// contains filtered or unexported fields
}
Syslog implements output.Output by formatting records as syslog and delegating transport.
Click to show internal directories.
Click to hide internal directories.