Documentation
¶
Index ¶
Constants ¶
const ( // DefaultTCPChannelSize is the default size of the data channel DefaultTCPChannelSize = 100 // DefaultTCPWorkers is the default number of worker goroutines DefaultTCPWorkers = 1 // DefaultTCPConnectTimeout is the default timeout for establishing TCP connections DefaultTCPConnectTimeout = 2 * time.Second // DefaultTCPWriteTimeout is the default timeout for writing data to TCP connections DefaultTCPWriteTimeout = 5 * time.Second // DefaultTCPStopTimeout is the default timeout for graceful shutdown DefaultTCPStopTimeout = 30 * time.Second )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TCP ¶
type TCP struct {
// contains filtered or unexported fields
}
TCP implements the Output interface for TCP connections
func (*TCP) ObserveBlitzOutputQueueSize ¶ added in v0.14.0
ObserveBlitzOutputQueueSize implements the output.ObservableCallbacks interface
func (*TCP) Stop ¶
Stop gracefully shuts down all workers and closes TCP connections Stop shall not be called more than once. If the provided context is done, Stop will return immediately even if workers are still shutting down.
Click to show internal directories.
Click to hide internal directories.