Documentation
¶
Index ¶
Constants ¶
const ( // DefaultUDPChannelSize is the default size of the data channel DefaultUDPChannelSize = 100 // DefaultUDPWorkers is the default number of worker goroutines DefaultUDPWorkers = 1 // DefaultUDPWriteTimeout is the default timeout for writing data to UDP connections DefaultUDPWriteTimeout = 5 * time.Second // DefaultUDPStopTimeout is the default timeout for graceful shutdown DefaultUDPStopTimeout = 30 * time.Second )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UDP ¶
type UDP struct {
// contains filtered or unexported fields
}
UDP implements the Output interface for UDP connections
func (*UDP) Stop ¶
Stop gracefully shuts down all workers and closes UDP connections Stop shall not be called more than once. If the provided context is done, Stop will return immediately even if workers are still shutting down.
Click to show internal directories.
Click to hide internal directories.