package
Version:
v0.16.0
Opens a new window with list of versions in this module.
Published: May 21, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package telemetry defines the supported telemetry signal types for blitz.
Supports returns true if the given type is present in the supported slice.
func Validate(generator, output []Type) error
Validate checks that the generator and output telemetry types have at least
one overlapping type. Returns an error if there is no overlap.
Type represents a telemetry signal type.
const (
Logs Type = "logs"
Metrics Type = "metrics"
Traces Type = "traces"
)
Valid returns true if the type is a known telemetry type.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.